@@ -4,7 +4,7 @@ use super::{
 	remotes::get_default_remote_in_repo, repository::repo, RepoPath,
 };
 use crate::error::{Error, Result};
-use git2::{Config, CredentialHelper};
+use git2::CredentialHelper;
 
 /// basic Authentication Credentials
 #[derive(Debug, Clone, Default, PartialEq)]
@@ -32,9 +32,11 @@ impl BasicAuthCredential {
 /// know if username and password are needed for this url
 pub fn need_username_password(repo_path: &RepoPath) -> Result<bool> {
 	let repo = repo(repo_path)?;
-	let url = repo
-		.find_remote(&get_default_remote_in_repo(&repo)?)?
-		.url()
+	let remote =
+		repo.find_remote(&get_default_remote_in_repo(&repo)?)?;
+	let url = remote
+		.pushurl()
+		.or_else(|| remote.url())
 		.ok_or(Error::UnknownRemote)?
 		.to_owned();
 	let is_http = url.starts_with("http");
@@ -53,9 +55,14 @@ pub fn extract_username_password(
 		.to_owned();
 	let mut helper = CredentialHelper::new(&url);
 
-	if let Ok(config) = Config::open_default() {
+	//TODO: look at Cred::credential_helper,
+	//if the username is in the url we need to set it here,
+	//I dont think `config` will pick it up
+
+	if let Ok(config) = repo.config() {
 		helper.config(&config);
 	}
+
 	Ok(match helper.execute() {
 		Some((username, password)) => {
 			BasicAuthCredential::new(Some(username), Some(password))
@@ -188,6 +195,25 @@ mod tests {
 		assert_eq!(need_username_password(repo_path).unwrap(), false);
 	}
 
+	#[test]
+	#[serial]
+	fn test_dont_need_username_password_if_pushurl_ssh() {
+		let (_td, repo) = repo_init().unwrap();
+		let root = repo.path().parent().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
+
+		repo.remote(DEFAULT_REMOTE_NAME, "http://user@github.com")
+			.unwrap();
+		repo.remote_set_pushurl(
+			DEFAULT_REMOTE_NAME,
+			Some("git@github.com:user/repo"),
+		)
+		.unwrap();
+
+		assert_eq!(need_username_password(repo_path).unwrap(), false);
+	}
+
 	#[test]
 	#[serial]
 	#[should_panic]
