@@ -8,6 +8,7 @@ pub mod branch;
 mod commit;
 mod commit_details;
 mod commit_files;
+mod commit_revert;
 mod commits_info;
 mod config;
 pub mod cred;
@@ -39,11 +40,12 @@ pub use branch::{
 	merge_rebase::merge_upstream_rebase, rename::rename_branch,
 	validate_branch_name, BranchCompare, BranchInfo,
 };
-pub use commit::{amend, commit, tag};
+pub use commit::{amend, commit, tag_commit};
 pub use commit_details::{
 	get_commit_details, CommitDetails, CommitMessage, CommitSignature,
 };
 pub use commit_files::get_commit_files;
+pub use commit_revert::{commit_revert, revert_commit, revert_head};
 pub use commits_info::{
 	get_commit_info, get_commits_info, CommitId, CommitInfo,
 };
@@ -60,9 +62,9 @@ pub use hunks::{reset_hunk, stage_hunk, unstage_hunk};
 pub use ignore::add_to_ignore;
 pub use logwalker::{LogWalker, LogWalkerFilter};
 pub use merge::{
-	abort_merge, abort_pending_rebase, continue_pending_rebase,
-	merge_branch, merge_commit, merge_msg, mergehead_ids,
-	rebase_progress,
+	abort_pending_rebase, abort_pending_state,
+	continue_pending_rebase, merge_branch, merge_commit, merge_msg,
+	mergehead_ids, rebase_progress,
 };
 pub use rebase::rebase_branch;
 pub use remotes::{
@@ -78,7 +80,7 @@ pub use stash::{
 };
 pub use state::{repo_state, RepoState};
 pub use tags::{
-	delete_tag, get_tags, get_tags_with_metadata, CommitTags,
+	delete_tag, get_tags, get_tags_with_metadata, CommitTags, Tag,
 	TagWithMetadata, Tags,
 };
 pub use tree::{tree_file_content, tree_files, TreeFile};
