@@ -25,7 +25,7 @@ use crate::{
 use anyhow::{bail, Result};
 use asyncgit::{
 	sync::{self, RepoPathRef},
-	AsyncGitNotification,
+	AsyncGitNotification, PushType,
 };
 use crossbeam_channel::Sender;
 use crossterm::event::{Event, KeyEvent};
@@ -674,6 +674,11 @@ impl App {
 				flags
 					.insert(NeedsUpdate::ALL | NeedsUpdate::COMMANDS);
 			}
+			InternalEvent::ShowInfoMsg(msg) => {
+				self.msg.show_info(msg.as_str())?;
+				flags
+					.insert(NeedsUpdate::ALL | NeedsUpdate::COMMANDS);
+			}
 			InternalEvent::Update(u) => flags.insert(u),
 			InternalEvent::OpenCommit => self.commit.show()?,
 			InternalEvent::PopupStashing(opts) => {
@@ -701,7 +706,7 @@ impl App {
 			InternalEvent::Tags => {
 				self.tags_popup.open()?;
 			}
-			InternalEvent::TabSwitch => self.set_tab(0)?,
+			InternalEvent::TabSwitchStatus => self.set_tab(0)?,
 			InternalEvent::InspectCommit(id, tags) => {
 				self.inspect_commit_popup.open(id, tags)?;
 				flags
@@ -723,8 +728,9 @@ impl App {
 				self.file_to_open = path;
 				flags.insert(NeedsUpdate::COMMANDS);
 			}
-			InternalEvent::Push(branch, force, delete) => {
-				self.push_popup.push(branch, force, delete)?;
+			InternalEvent::Push(branch, push_type, force, delete) => {
+				self.push_popup
+					.push(branch, push_type, force, delete)?;
 				flags.insert(NeedsUpdate::ALL);
 			}
 			InternalEvent::Pull(branch) => {
@@ -790,6 +796,7 @@ impl App {
 		Ok(flags)
 	}
 
+	#[allow(clippy::too_many_lines)]
 	fn process_confirmed_action(
 		&mut self,
 		action: Action,
@@ -850,6 +857,7 @@ impl App {
 						|name| {
 							InternalEvent::Push(
 								name.to_string(),
+								PushType::Branch,
 								false,
 								true,
 							)
@@ -867,20 +875,40 @@ impl App {
 						error.to_string(),
 					));
 				} else {
+					let remote = sync::get_default_remote(
+						&self.repo.borrow(),
+					)?;
+
+					self.queue.push(InternalEvent::ConfirmAction(
+						Action::DeleteRemoteTag(tag_name, remote),
+					));
+
 					flags.insert(NeedsUpdate::ALL);
 					self.tags_popup.update_tags()?;
 				}
 			}
+			Action::DeleteRemoteTag(tag_name, _remote) => {
+				self.queue.push(InternalEvent::Push(
+					tag_name,
+					PushType::Tag,
+					false,
+					true,
+				));
+			}
 			Action::ForcePush(branch, force) => {
-				self.queue
-					.push(InternalEvent::Push(branch, force, false));
+				self.queue.push(InternalEvent::Push(
+					branch,
+					PushType::Branch,
+					force,
+					false,
+				));
 			}
 			Action::PullMerge { rebase, .. } => {
 				self.pull_popup.try_conflict_free_merge(rebase);
 				flags.insert(NeedsUpdate::ALL);
 			}
-			Action::AbortMerge => {
-				self.status_tab.abort_merge();
+			Action::AbortRevert | Action::AbortMerge => {
+				self.status_tab.revert_pending_state();
 				flags.insert(NeedsUpdate::ALL);
 			}
 			Action::AbortRebase => {
