@@ -42,6 +42,7 @@ pub struct BranchListComponent {
 	repo: RepoPathRef,
 	branches: Vec<BranchInfo>,
 	local: bool,
+	has_remotes: bool,
 	visible: bool,
 	selection: u16,
 	scroll: VerticalScroll,
@@ -200,7 +201,7 @@ impl Component for BranchListComponent {
 
 			out.push(CommandInfo::new(
 				strings::commands::fetch_remotes(&self.key_config),
-				true,
+				self.has_remotes,
 				!self.local,
 			));
 		}
@@ -243,6 +244,7 @@ impl Component for BranchListComponent {
 					.map(Into::into);
 			} else if e == self.key_config.keys.tab_toggle {
 				self.local = !self.local;
+				self.check_remotes();
 				self.update_branches()?;
 			} else if e == self.key_config.keys.enter {
 				try_or_popup!(
@@ -297,7 +299,9 @@ impl Component for BranchListComponent {
 					self.queue
 						.push(InternalEvent::CompareCommits(b, None));
 				}
-			} else if e == self.key_config.keys.pull && !self.local {
+			} else if e == self.key_config.keys.pull
+				&& !self.local && self.has_remotes
+			{
 				self.queue.push(InternalEvent::FetchRemotes);
 			} else if e == self.key_config.keys.cmd_bar_toggle {
 				//do not consume if its the more key
@@ -333,6 +337,7 @@ impl BranchListComponent {
 		Self {
 			branches: Vec::new(),
 			local: true,
+			has_remotes: false,
 			visible: false,
 			selection: 0,
 			scroll: VerticalScroll::new(),
@@ -352,9 +357,19 @@ impl BranchListComponent {
 		Ok(())
 	}
 
+	fn check_remotes(&mut self) {
+		if !self.local {
+			self.has_remotes =
+				get_branches_info(&self.repo.borrow(), false)
+					.map(|branches| !branches.is_empty())
+					.unwrap_or(false);
+		}
+	}
+
 	/// fetch list of branches
 	pub fn update_branches(&mut self) -> Result<()> {
 		if self.is_visible() {
+			self.check_remotes();
 			self.branches =
 				get_branches_info(&self.repo.borrow(), self.local)?;
 			//remove remote branch called `HEAD`
@@ -431,7 +446,7 @@ impl BranchListComponent {
 
 		if sync::repo_state(&self.repo.borrow())? != RepoState::Clean
 		{
-			self.queue.push(InternalEvent::TabSwitch);
+			self.queue.push(InternalEvent::TabSwitchStatus);
 		}
 
 		Ok(())
