@@ -30,10 +30,16 @@ use tui::{
 	Frame,
 };
 
+enum CommitResult {
+	ComitDone,
+	Aborted,
+}
+
 enum Mode {
 	Normal,
 	Amend(CommitId),
 	Merge(Vec<CommitId>),
+	Revert,
 }
 
 pub struct CommitComponent {
@@ -175,11 +181,23 @@ impl CommitComponent {
 		}
 
 		let msg = self.input.get_text().to_string();
-		self.input.clear();
-		self.commit_with_msg(msg)
+
+		if matches!(
+			self.commit_with_msg(msg)?,
+			CommitResult::ComitDone
+		) {
+			self.hide();
+			self.queue.push(InternalEvent::Update(NeedsUpdate::ALL));
+			self.input.clear();
+		}
+
+		Ok(())
 	}
 
-	fn commit_with_msg(&mut self, msg: String) -> Result<()> {
+	fn commit_with_msg(
+		&mut self,
+		msg: String,
+	) -> Result<CommitResult> {
 		if let HookResult::NotOk(e) =
 			sync::hooks_pre_commit(&self.repo.borrow())?
 		{
@@ -188,7 +206,7 @@ impl CommitComponent {
 				"pre-commit hook error:\n{}",
 				e
 			)));
-			return Ok(());
+			return Ok(CommitResult::Aborted);
 		}
 		let mut msg = message_prettify(msg, Some(b'#'))?;
 		if let HookResult::NotOk(e) =
@@ -199,28 +217,22 @@ impl CommitComponent {
 				"commit-msg hook error:\n{}",
 				e
 			)));
-			return Ok(());
+			return Ok(CommitResult::Aborted);
 		}
 
-		let res = match &self.mode {
-			Mode::Normal => sync::commit(&self.repo.borrow(), &msg),
+		match &self.mode {
+			Mode::Normal => sync::commit(&self.repo.borrow(), &msg)?,
 			Mode::Amend(amend) => {
-				sync::amend(&self.repo.borrow(), *amend, &msg)
+				sync::amend(&self.repo.borrow(), *amend, &msg)?
 			}
 			Mode::Merge(ids) => {
-				sync::merge_commit(&self.repo.borrow(), &msg, ids)
+				sync::merge_commit(&self.repo.borrow(), &msg, ids)?
+			}
+			Mode::Revert => {
+				sync::commit_revert(&self.repo.borrow(), &msg)?
 			}
 		};
 
-		if let Err(e) = res {
-			log::error!("commit error: {}", &e);
-			self.queue.push(InternalEvent::ShowErrorMsg(format!(
-				"commit failed:\n{}",
-				&e
-			)));
-			return Ok(());
-		}
-
 		if let HookResult::NotOk(e) =
 			sync::hooks_post_commit(&self.repo.borrow())?
 		{
@@ -231,11 +243,7 @@ impl CommitComponent {
 			)));
 		}
 
-		self.hide();
-
-		self.queue.push(InternalEvent::Update(NeedsUpdate::ALL));
-
-		Ok(())
+		Ok(CommitResult::ComitDone)
 	}
 
 	fn can_commit(&self) -> bool {
@@ -376,31 +384,40 @@ impl Component for CommitComponent {
 
 		self.mode = Mode::Normal;
 
-		self.mode = if sync::repo_state(&self.repo.borrow())?
-			== RepoState::Merge
-		{
-			let ids = sync::mergehead_ids(&self.repo.borrow())?;
-			self.input.set_title(strings::commit_title_merge());
-			self.input
-				.set_text(sync::merge_msg(&self.repo.borrow())?);
-			Mode::Merge(ids)
-		} else {
-			self.commit_template = get_config_string(
-				&self.repo.borrow(),
-				"commit.template",
-			)
-			.ok()
-			.flatten()
-			.and_then(|path| read_to_string(path).ok());
+		let repo_state = sync::repo_state(&self.repo.borrow())?;
 
-			if self.is_empty() {
-				if let Some(s) = &self.commit_template {
-					self.input.set_text(s.clone());
-				}
+		self.mode = match repo_state {
+			RepoState::Merge => {
+				let ids = sync::mergehead_ids(&self.repo.borrow())?;
+				self.input.set_title(strings::commit_title_merge());
+				self.input
+					.set_text(sync::merge_msg(&self.repo.borrow())?);
+				Mode::Merge(ids)
 			}
+			RepoState::Revert => {
+				self.input.set_title(strings::commit_title_revert());
+				self.input
+					.set_text(sync::merge_msg(&self.repo.borrow())?);
+				Mode::Revert
+			}
+			_ => {
+				self.commit_template = get_config_string(
+					&self.repo.borrow(),
+					"commit.template",
+				)
+				.ok()
+				.flatten()
+				.and_then(|path| read_to_string(path).ok());
 
-			self.input.set_title(strings::commit_title());
-			Mode::Normal
+				if self.is_empty() {
+					if let Some(s) = &self.commit_template {
+						self.input.set_text(s.clone());
+					}
+				}
+
+				self.input.set_title(strings::commit_title());
+				Mode::Normal
+			}
 		};
 
 		self.input.show()?;
