@@ -183,6 +183,10 @@ impl ConfirmComponent {
                         &self.key_config,
                         tag_name,
                     ),
+                ),
+				Action::DeleteRemoteTag(_tag_name,remote) => (
+                    strings::confirm_title_delete_tag_remote(),
+                    strings::confirm_msg_delete_tag_remote(remote),
                 ),
                 Action::ForcePush(branch, _force) => (
                     strings::confirm_title_force_push(
@@ -199,11 +203,15 @@ impl ConfirmComponent {
                 ),
                 Action::AbortMerge => (
                     strings::confirm_title_abortmerge(),
-                    strings::confirm_msg_abortmerge(),
+                    strings::confirm_msg_revertchanges(),
                 ),
 				Action::AbortRebase => (
                     strings::confirm_title_abortrebase(),
                     strings::confirm_msg_abortrebase(),
+                ),
+				Action::AbortRevert => (
+                    strings::confirm_title_abortrevert(),
+                    strings::confirm_msg_revertchanges(),
                 ),
             };
 		}
