@@ -14,8 +14,14 @@ use asyncgit::sync::{self, CommitId, RepoPathRef};
 use crossterm::event::Event;
 use tui::{backend::Backend, layout::Rect, Frame};
 
+enum Mode {
+	Name,
+	Annotation { tag_name: String },
+}
+
 pub struct TagCommitComponent {
 	repo: RepoPathRef,
+	mode: Mode,
 	input: TextInputComponent,
 	commit_id: Option<CommitId>,
 	queue: Queue,
@@ -47,8 +53,14 @@ impl Component for TagCommitComponent {
 				strings::commands::tag_commit_confirm_msg(
 					&self.key_config,
 				),
+				self.is_valid_tag(),
 				true,
-				true,
+			));
+
+			out.push(CommandInfo::new(
+				strings::commands::tag_annotate_msg(&self.key_config),
+				self.is_valid_tag(),
+				matches!(self.mode, Mode::Name),
 			));
 		}
 
@@ -62,8 +74,26 @@ impl Component for TagCommitComponent {
 			}
 
 			if let Event::Key(e) = ev {
-				if e == self.key_config.keys.enter {
+				if e == self.key_config.keys.enter
+					&& self.is_valid_tag()
+				{
 					self.tag();
+				} else if e == self.key_config.keys.tag_annotate
+					&& self.is_valid_tag()
+				{
+					let tag_name: String =
+						self.input.get_text().into();
+
+					self.input.clear();
+					self.input.set_title(
+						strings::tag_popup_annotation_title(
+							&tag_name,
+						),
+					);
+					self.input.set_default_msg(
+						strings::tag_popup_annotation_msg(),
+					);
+					self.mode = Mode::Annotation { tag_name };
 				}
 
 				return Ok(EventState::Consumed);
@@ -81,6 +111,9 @@ impl Component for TagCommitComponent {
 	}
 
 	fn show(&mut self) -> Result<()> {
+		self.mode = Mode::Name;
+		self.input.set_title(strings::tag_popup_name_title());
+		self.input.set_default_msg(strings::tag_popup_name_msg());
 		self.input.show()?;
 
 		Ok(())
@@ -100,13 +133,14 @@ impl TagCommitComponent {
 			input: TextInputComponent::new(
 				theme,
 				key_config.clone(),
-				&strings::tag_commit_popup_title(&key_config),
-				&strings::tag_commit_popup_msg(&key_config),
+				&strings::tag_popup_name_title(),
+				&strings::tag_popup_name_msg(),
 				true,
 			),
 			commit_id: None,
 			key_config,
 			repo,
+			mode: Mode::Name,
 		}
 	}
 
@@ -118,13 +152,29 @@ impl TagCommitComponent {
 		Ok(())
 	}
 
+	fn is_valid_tag(&self) -> bool {
+		!self.input.get_text().is_empty()
+	}
+
+	fn tag_info(&self) -> (String, Option<String>) {
+		match &self.mode {
+			Mode::Name => (self.input.get_text().into(), None),
+			Mode::Annotation { tag_name } => {
+				(tag_name.clone(), Some(self.input.get_text().into()))
+			}
+		}
+	}
+
 	///
 	pub fn tag(&mut self) {
+		let (tag_name, tag_annotation) = self.tag_info();
+
 		if let Some(commit_id) = self.commit_id {
-			let result = sync::tag(
+			let result = sync::tag_commit(
 				&self.repo.borrow(),
 				&commit_id,
-				self.input.get_text(),
+				&tag_name,
+				tag_annotation.as_deref(),
 			);
 			match result {
 				Ok(_) => {
@@ -136,7 +186,10 @@ impl TagCommitComponent {
 					));
 				}
 				Err(e) => {
+					// go back to tag name if something goes wrong
+					self.input.set_text(tag_name);
 					self.hide();
+
 					log::error!("e: {}", e,);
 					self.queue.push(InternalEvent::ShowErrorMsg(
 						format!("tag error:\n{}", e,),
