@@ -87,12 +87,19 @@ pub fn msg_opening_editor(_key_config: &SharedKeyConfig) -> String {
 pub fn msg_title_error(_key_config: &SharedKeyConfig) -> String {
 	"Error".to_string()
 }
+pub fn msg_title_info(_key_config: &SharedKeyConfig) -> String {
+	"Info".to_string()
+}
 pub fn commit_title() -> String {
 	"Commit".to_string()
 }
+
 pub fn commit_title_merge() -> String {
 	"Commit (Merge)".to_string()
 }
+pub fn commit_title_revert() -> String {
+	"Commit (Revert)".to_string()
+}
 pub fn commit_title_amend() -> String {
 	"Commit (Amend)".to_string()
 }
@@ -156,7 +163,10 @@ pub fn confirm_msg_merge(
 pub fn confirm_title_abortmerge() -> String {
 	"Abort merge?".to_string()
 }
-pub fn confirm_msg_abortmerge() -> String {
+pub fn confirm_title_abortrevert() -> String {
+	"Abort revert?".to_string()
+}
+pub fn confirm_msg_revertchanges() -> String {
 	"This will revert all uncommitted changes. Are you sure?"
 		.to_string()
 }
@@ -236,6 +246,12 @@ pub fn confirm_msg_delete_tag(
 ) -> String {
 	format!("Confirm deleting Tag: '{}' ?", tag_name)
 }
+pub fn confirm_title_delete_tag_remote() -> String {
+	"Delete Tag (remote)".to_string()
+}
+pub fn confirm_msg_delete_tag_remote(remote_name: &str) -> String {
+	format!("Confirm deleting tag on remote '{}'?", remote_name)
+}
 pub fn confirm_title_force_push(
 	_key_config: &SharedKeyConfig,
 ) -> String {
@@ -256,13 +272,17 @@ pub fn log_title(_key_config: &SharedKeyConfig) -> String {
 pub fn blame_title(_key_config: &SharedKeyConfig) -> String {
 	"Blame".to_string()
 }
-pub fn tag_commit_popup_title(
-	_key_config: &SharedKeyConfig,
-) -> String {
+pub fn tag_popup_name_title() -> String {
 	"Tag".to_string()
 }
-pub fn tag_commit_popup_msg(_key_config: &SharedKeyConfig) -> String {
-	"type tag".to_string()
+pub fn tag_popup_name_msg() -> String {
+	"type tag name".to_string()
+}
+pub fn tag_popup_annotation_title(name: &str) -> String {
+	format!("Tag Annotation ({})", name)
+}
+pub fn tag_popup_annotation_msg() -> String {
+	"type tag annotation".to_string()
 }
 pub fn stashlist_title(_key_config: &SharedKeyConfig) -> String {
 	"Stashes".to_string()
@@ -513,6 +533,18 @@ pub mod commands {
 			CMD_GROUP_LOG,
 		)
 	}
+	pub fn show_tag_annotation(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Annotation [{}]",
+				key_config.get_hint(key_config.keys.move_right),
+			),
+			"show tag annotation",
+			CMD_GROUP_LOG,
+		)
+	}
 	pub fn diff_home_end(
 		key_config: &SharedKeyConfig,
 	) -> CommandText {
@@ -647,6 +679,17 @@ pub mod commands {
 		)
 	}
 
+	pub fn abort_revert(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"Abort revert [{}]",
+				key_config.get_hint(key_config.keys.abort_merge),
+			),
+			"abort ongoing revert",
+			CMD_GROUP_GENERAL,
+		)
+	}
+
 	pub fn continue_rebase(
 		key_config: &SharedKeyConfig,
 	) -> CommandText {
@@ -1035,6 +1078,19 @@ pub mod commands {
 			CMD_GROUP_LOG,
 		)
 	}
+	pub fn revert_commit(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Revert [{}]",
+				key_config
+					.get_hint(key_config.keys.status_reset_item),
+			),
+			"revert commit",
+			CMD_GROUP_LOG,
+		)
+	}
 	pub fn tag_commit_confirm_msg(
 		key_config: &SharedKeyConfig,
 	) -> CommandText {
@@ -1047,6 +1103,20 @@ pub mod commands {
 			CMD_GROUP_LOG,
 		)
 	}
+
+	pub fn tag_annotate_msg(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Annotate [{}]",
+				key_config.get_hint(key_config.keys.tag_annotate),
+			),
+			"annotate tag",
+			CMD_GROUP_LOG,
+		)
+	}
+
 	pub fn create_branch_confirm_msg(
 		key_config: &SharedKeyConfig,
 	) -> CommandText {
