@@ -14,10 +14,13 @@ use crate::{
 use anyhow::Result;
 use asyncgit::{
 	cached,
-	sync::{self, status::StatusType, RepoState},
+	sync::{
+		self, get_branches_info, status::StatusType, RepoPath,
+		RepoPathRef, RepoState,
+	},
 	sync::{BranchCompare, CommitId},
 	AsyncDiff, AsyncGitNotification, AsyncStatus, DiffParams,
-	DiffType, StatusParams, CWD,
+	DiffType, PushType, StatusParams,
 };
 use crossbeam_channel::Sender;
 use crossterm::event::Event;
@@ -56,6 +59,7 @@ enum DiffTarget {
 }
 
 pub struct Status {
+	repo: RepoPathRef,
 	visible: bool,
 	focus: Focus,
 	diff_target: DiffTarget,
@@ -79,7 +83,7 @@ impl DrawableComponent for Status {
 		f: &mut tui::Frame<B>,
 		rect: tui::layout::Rect,
 	) -> Result<()> {
-		let repo_unclean = Self::repo_state_unclean();
+		let repo_unclean = self.repo_state_unclean();
 		let rects = if repo_unclean {
 			Layout::default()
 				.direction(Direction::Vertical)
@@ -134,7 +138,7 @@ impl DrawableComponent for Status {
 		self.draw_branch_state(f, &left_chunks);
 
 		if repo_unclean {
-			Self::draw_repo_state(f, rects[1]);
+			self.draw_repo_state(f, rects[1]);
 		}
 
 		Ok(())
@@ -146,47 +150,61 @@ impl Status {
 
 	///
 	pub fn new(
+		repo: RepoPathRef,
 		queue: &Queue,
 		sender: &Sender<AsyncGitNotification>,
 		theme: SharedTheme,
 		key_config: SharedKeyConfig,
 		options: SharedOptions,
 	) -> Self {
+		let repo_clone = repo.borrow().clone();
 		Self {
 			queue: queue.clone(),
 			visible: true,
 			focus: Focus::WorkDir,
 			diff_target: DiffTarget::WorkingDir,
 			index_wd: ChangesComponent::new(
+				repo.clone(),
 				&strings::title_status(&key_config),
 				true,
 				true,
 				queue.clone(),
 				theme.clone(),
 				key_config.clone(),
+				options.clone(),
 			),
 			index: ChangesComponent::new(
+				repo.clone(),
 				&strings::title_index(&key_config),
 				false,
 				false,
 				queue.clone(),
 				theme.clone(),
 				key_config.clone(),
+				options.clone(),
 			),
 			diff: DiffComponent::new(
+				repo.clone(),
 				queue.clone(),
 				theme,
 				key_config.clone(),
 				false,
 			),
-			git_diff: AsyncDiff::new(sender),
-			git_status_workdir: AsyncStatus::new(sender.clone()),
-			git_status_stage: AsyncStatus::new(sender.clone()),
+			git_diff: AsyncDiff::new(repo_clone.clone(), sender),
+			git_status_workdir: AsyncStatus::new(
+				repo_clone.clone(),
+				sender.clone(),
+			),
+			git_status_stage: AsyncStatus::new(
+				repo_clone,
+				sender.clone(),
+			),
 			git_action_executed: false,
 			git_branch_state: None,
-			git_branch_name: cached::BranchName::new(CWD),
+			git_branch_name: cached::BranchName::new(repo.clone()),
 			key_config,
 			options,
+			repo,
 		}
 	}
 
@@ -230,11 +248,11 @@ impl Status {
 		}
 	}
 
-	fn repo_state_text(state: &RepoState) -> String {
+	fn repo_state_text(repo: &RepoPath, state: &RepoState) -> String {
 		match state {
 			RepoState::Merge => {
 				let ids =
-					sync::mergehead_ids(CWD).unwrap_or_default();
+					sync::mergehead_ids(repo).unwrap_or_default();
 
 				format!(
 					"Commits: {}",
@@ -244,7 +262,7 @@ impl Status {
 				)
 			}
 			RepoState::Rebase => {
-				if let Ok(p) = sync::rebase_progress(CWD) {
+				if let Ok(p) = sync::rebase_progress(repo) {
 					format!(
 						"Step: {}/{} Current Commit: {}",
 						p.current + 1,
@@ -258,17 +276,31 @@ impl Status {
 					String::new()
 				}
 			}
+			RepoState::Revert => {
+				format!(
+					"Revert {}",
+					sync::revert_head(repo)
+						.ok()
+						.as_ref()
+						.map(CommitId::get_short_string)
+						.unwrap_or_default(),
+				)
+			}
 			_ => format!("{:?}", state),
 		}
 	}
 
 	fn draw_repo_state<B: tui::backend::Backend>(
+		&self,
 		f: &mut tui::Frame<B>,
 		r: tui::layout::Rect,
 	) {
-		if let Ok(state) = sync::repo_state(CWD) {
+		if let Ok(state) = sync::repo_state(&self.repo.borrow()) {
 			if state != RepoState::Clean {
-				let txt = Self::repo_state_text(&state);
+				let txt = Self::repo_state_text(
+					&self.repo.borrow(),
+					&state,
+				);
 
 				let w = Paragraph::new(txt)
 					.block(
@@ -288,8 +320,8 @@ impl Status {
 		}
 	}
 
-	fn repo_state_unclean() -> bool {
-		if let Ok(state) = sync::repo_state(CWD) {
+	fn repo_state_unclean(&self) -> bool {
+		if let Ok(state) = sync::repo_state(&self.repo.borrow()) {
 			if state != RepoState::Clean {
 				return true;
 			}
@@ -399,7 +431,7 @@ impl Status {
 			AsyncGitNotification::Diff => self.update_diff()?,
 			AsyncGitNotification::Status => self.update_status()?,
 			AsyncGitNotification::Push
-			| AsyncGitNotification::Fetch
+			| AsyncGitNotification::Pull
 			| AsyncGitNotification::CommitFiles => {
 				self.branch_compare();
 			}
@@ -495,7 +527,10 @@ impl Status {
 
 	/// called after confirmation
 	pub fn reset(&mut self, item: &ResetItem) -> bool {
-		if let Err(e) = sync::reset_workdir(CWD, item.path.as_str()) {
+		if let Err(e) = sync::reset_workdir(
+			&self.repo.borrow(),
+			item.path.as_str(),
+		) {
 			self.queue.push(InternalEvent::ShowErrorMsg(format!(
 				"reset failed:\n{}",
 				e
@@ -523,13 +558,22 @@ impl Status {
 					));
 				} else {
 					self.queue.push(InternalEvent::Push(
-						branch, force, false,
+						branch,
+						PushType::Branch,
+						force,
+						false,
 					));
 				}
 			}
 		}
 	}
 
+	fn has_remotes(&self) -> bool {
+		get_branches_info(&self.repo.borrow(), false)
+			.map(|l| !l.is_empty())
+			.unwrap_or(false)
+	}
+
 	fn pull(&self) {
 		if let Some(branch) = self.git_branch_name.last() {
 			self.queue.push(InternalEvent::Pull(branch));
@@ -540,15 +584,18 @@ impl Status {
 		try_or_popup!(
 			self,
 			"undo commit failed:",
-			sync::utils::undo_last_commit(CWD)
+			sync::utils::undo_last_commit(&self.repo.borrow())
 		);
 	}
 
 	fn branch_compare(&mut self) {
 		self.git_branch_state =
 			self.git_branch_name.last().and_then(|branch| {
-				sync::branch_compare_upstream(CWD, branch.as_str())
-					.ok()
+				sync::branch_compare_upstream(
+					&self.repo.borrow(),
+					branch.as_str(),
+				)
+				.ok()
 			});
 	}
 
@@ -556,27 +603,44 @@ impl Status {
 		self.git_branch_state
 			.as_ref()
 			.map_or(true, |state| state.ahead > 0)
+			&& self.has_remotes()
 	}
 
-	fn can_abort_merge() -> bool {
-		sync::repo_state(CWD).unwrap_or(RepoState::Clean)
+	fn can_pull(&self) -> bool {
+		self.has_remotes() && self.git_branch_state.is_some()
+	}
+
+	fn can_abort_merge(&self) -> bool {
+		sync::repo_state(&self.repo.borrow())
+			.unwrap_or(RepoState::Clean)
 			== RepoState::Merge
 	}
 
-	fn pending_rebase() -> bool {
-		sync::repo_state(CWD).unwrap_or(RepoState::Clean)
+	fn pending_rebase(&self) -> bool {
+		sync::repo_state(&self.repo.borrow())
+			.unwrap_or(RepoState::Clean)
 			== RepoState::Rebase
 	}
 
-	pub fn abort_merge(&self) {
-		try_or_popup!(self, "abort merge", sync::abort_merge(CWD));
+	fn pending_revert(&self) -> bool {
+		sync::repo_state(&self.repo.borrow())
+			.unwrap_or(RepoState::Clean)
+			== RepoState::Revert
+	}
+
+	pub fn revert_pending_state(&self) {
+		try_or_popup!(
+			self,
+			"revert pending state",
+			sync::abort_pending_state(&self.repo.borrow())
+		);
 	}
 
 	pub fn abort_rebase(&self) {
 		try_or_popup!(
 			self,
 			"abort rebase",
-			sync::abort_pending_rebase(CWD)
+			sync::abort_pending_rebase(&self.repo.borrow())
 		);
 	}
 
@@ -584,7 +648,7 @@ impl Status {
 		try_or_popup!(
 			self,
 			"continue rebase",
-			sync::continue_pending_rebase(CWD)
+			sync::continue_pending_rebase(&self.repo.borrow())
 		);
 	}
 
@@ -635,7 +699,7 @@ impl Status {
 	fn can_commit(&self) -> bool {
 		self.index.focused()
 			&& !self.index.is_empty()
-			&& !Self::pending_rebase()
+			&& !self.pending_rebase()
 	}
 }
 
@@ -685,32 +749,39 @@ impl Component for Status {
 			));
 			out.push(CommandInfo::new(
 				strings::commands::status_pull(&self.key_config),
-				true,
+				self.can_pull(),
 				!focus_on_diff,
 			));
 
 			out.push(CommandInfo::new(
 				strings::commands::undo_commit(&self.key_config),
 				true,
-				(!Self::pending_rebase() && !focus_on_diff)
+				(!self.pending_rebase() && !focus_on_diff)
 					|| force_all,
 			));
 
 			out.push(CommandInfo::new(
 				strings::commands::abort_merge(&self.key_config),
 				true,
-				Self::can_abort_merge() || force_all,
+				self.can_abort_merge() || force_all,
 			));
 
 			out.push(CommandInfo::new(
 				strings::commands::continue_rebase(&self.key_config),
 				true,
-				Self::pending_rebase() || force_all,
+				self.pending_rebase() || force_all,
 			));
+
 			out.push(CommandInfo::new(
 				strings::commands::abort_rebase(&self.key_config),
 				true,
-				Self::pending_rebase() || force_all,
+				self.pending_rebase() || force_all,
+			));
+
+			out.push(CommandInfo::new(
+				strings::commands::abort_revert(&self.key_config),
+				true,
+				self.pending_revert() || force_all,
 			));
 		}
 
@@ -745,7 +816,7 @@ impl Component for Status {
 			}
 
 			if let Event::Key(k) = ev {
-				return if k == self.key_config.edit_file
+				return if k == self.key_config.keys.edit_file
 					&& (self.can_focus_diff()
 						|| self.is_focus_on_diff())
 				{
@@ -757,58 +828,59 @@ impl Component for Status {
 						);
 					}
 					Ok(EventState::Consumed)
-				} else if k == self.key_config.open_commit
+				} else if k == self.key_config.keys.open_commit
 					&& self.can_commit()
 				{
 					self.queue.push(InternalEvent::OpenCommit);
 					Ok(EventState::Consumed)
-				} else if k == self.key_config.toggle_workarea
+				} else if k == self.key_config.keys.toggle_workarea
 					&& !self.is_focus_on_diff()
 				{
 					self.switch_focus(self.focus.toggled_focus())
 						.map(Into::into)
-				} else if k == self.key_config.focus_right
+				} else if k == self.key_config.keys.focus_right
 					&& self.can_focus_diff()
 				{
 					self.switch_focus(Focus::Diff).map(Into::into)
-				} else if k == self.key_config.focus_left {
+				} else if k == self.key_config.keys.focus_left {
 					self.switch_focus(match self.diff_target {
 						DiffTarget::Stage => Focus::Stage,
 						DiffTarget::WorkingDir => Focus::WorkDir,
 					})
 					.map(Into::into)
-				} else if k == self.key_config.move_down
+				} else if k == self.key_config.keys.move_down
 					&& self.focus == Focus::WorkDir
 					&& !self.index.is_empty()
 				{
 					self.switch_focus(Focus::Stage).map(Into::into)
-				} else if k == self.key_config.move_up
+				} else if k == self.key_config.keys.move_up
 					&& self.focus == Focus::Stage
 					&& !self.index_wd.is_empty()
 				{
 					self.switch_focus(Focus::WorkDir).map(Into::into)
-				} else if k == self.key_config.select_branch
+				} else if k == self.key_config.keys.select_branch
 					&& !self.is_focus_on_diff()
 				{
 					self.queue.push(InternalEvent::SelectBranch);
 					Ok(EventState::Consumed)
-				} else if k == self.key_config.force_push
+				} else if k == self.key_config.keys.force_push
 					&& !self.is_focus_on_diff()
 					&& self.can_push()
 				{
 					self.push(true);
 					Ok(EventState::Consumed)
-				} else if k == self.key_config.push
+				} else if k == self.key_config.keys.push
 					&& !self.is_focus_on_diff()
 				{
 					self.push(false);
 					Ok(EventState::Consumed)
-				} else if k == self.key_config.pull
+				} else if k == self.key_config.keys.pull
 					&& !self.is_focus_on_diff()
+					&& self.can_pull()
 				{
 					self.pull();
 					Ok(EventState::Consumed)
-				} else if k == self.key_config.undo_commit
+				} else if k == self.key_config.keys.undo_commit
 					&& !self.is_focus_on_diff()
 				{
 					self.undo_last_commit();
@@ -816,24 +888,30 @@ impl Component for Status {
 						NeedsUpdate::ALL,
 					));
 					Ok(EventState::Consumed)
-				} else if k == self.key_config.abort_merge
-					&& Self::can_abort_merge()
-				{
-					self.queue.push(InternalEvent::ConfirmAction(
-						Action::AbortMerge,
-					));
+				} else if k == self.key_config.keys.abort_merge {
+					if self.can_abort_merge() {
+						self.queue.push(
+							InternalEvent::ConfirmAction(
+								Action::AbortMerge,
+							),
+						);
+					} else if self.pending_rebase() {
+						self.queue.push(
+							InternalEvent::ConfirmAction(
+								Action::AbortRebase,
+							),
+						);
+					} else if self.pending_revert() {
+						self.queue.push(
+							InternalEvent::ConfirmAction(
+								Action::AbortRevert,
+							),
+						);
+					}
 
 					Ok(EventState::Consumed)
-				} else if k == self.key_config.abort_merge
-					&& Self::pending_rebase()
-				{
-					self.queue.push(InternalEvent::ConfirmAction(
-						Action::AbortRebase,
-					));
-
-					Ok(EventState::Consumed)
-				} else if k == self.key_config.rebase_branch
-					&& Self::pending_rebase()
+				} else if k == self.key_config.keys.rebase_branch
+					&& self.pending_rebase()
 				{
 					self.continue_rebase();
 					self.queue.push(InternalEvent::Update(
